==> kubernetes-model-admissionregistration-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingWebhookConfigurationFluent<A extends ValidatingWebhookConfigurationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToWebhooks(Integer index,ValidatingWebhook item);
  public A setToWebhooks(Integer index,ValidatingWebhook item);
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items);
  public A addAllToWebhooks(Collection<ValidatingWebhook> items);
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items);
  public A removeAllFromWebhooks(Collection<ValidatingWebhook> items);
  public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWebhooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingWebhook> getWebhooks();
  public List<ValidatingWebhook> buildWebhooks();
  public ValidatingWebhook buildWebhook(Integer index);
  public ValidatingWebhook buildFirstWebhook();
  public ValidatingWebhook buildLastWebhook();
  public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
  public Boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
  public A withWebhooks(List<ValidatingWebhook> webhooks);
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... webhooks);
  public Boolean hasWebhooks();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item);
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(Integer index,ValidatingWebhook item);
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(Integer index);
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ValidatingWebhookConfigurationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface WebhooksNested<N> extends Nested<N>,ValidatingWebhookFluent<ValidatingWebhookConfigurationFluent.WebhooksNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingWebhookConfigurationFluent<A extends ValidatingWebhookConfigurationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToWebhooks(int index,ValidatingWebhook item);
  public A setToWebhooks(int index,ValidatingWebhook item);
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items);
  public A addAllToWebhooks(Collection<ValidatingWebhook> items);
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items);
  public A removeAllFromWebhooks(Collection<ValidatingWebhook> items);
  public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWebhooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingWebhook> getWebhooks();
  public List<ValidatingWebhook> buildWebhooks();
  public ValidatingWebhook buildWebhook(int index);
  public ValidatingWebhook buildFirstWebhook();
  public ValidatingWebhook buildLastWebhook();
  public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
  public Boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
  public A withWebhooks(List<ValidatingWebhook> webhooks);
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... webhooks);
  public Boolean hasWebhooks();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item);
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,ValidatingWebhook item);
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ValidatingWebhookConfigurationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface WebhooksNested<N> extends Nested<N>,ValidatingWebhookFluent<ValidatingWebhookConfigurationFluent.WebhooksNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}
